import tileProviders, { TileProviders } from './tile-providers';

/**
 * An identifier for tiles (can also be used for tile layers)
 */
export interface TileKeyObject {
  /**A tile provider id ('osm', 'otm', ...) */
  provider: keyof TileProviders;
  /**The zoom level (integer) */
  zoomLevel: number;
  /**The X coordinate (integer)*/
  x: number;
  /**The Y coordinate (integer) */
  y: number;
}

/**
 * A point identified by its longitude and latitude
 */
export interface geoPoint {
  lon: number;
  lat: number;
}

/**
 * A map scope.
 *
 * This object contains what's needed to identify the state of the map
 *
 */
export interface MapScope {
  center: geoPoint;
  zoom: number;
  tileProvider: keyof TileProviders;
}

/**
 * A point
 */
export interface Point {
  /**The X coordinate (integer)*/
  x: number;
  /**The Y coordinate (integer) */
  y: number;
}

/**
 * A rectangle
 */
export interface Rectangle {
  topLeft: Point;
  bottomRight: Point;
}
